## PR Checklist for maintainers

- [ ] PR targets the correct branch
- [ ] Tests have run and passed for the latest commit on the source branch
- [ ] Check that the code can still be installed if new packages are imported
- [ ] Quality of new/changed code is acceptable
- [ ] Quality of new/changed unit tests is acceptable
- [ ] Check that the names of the new functions are homogenous with the rest of the code in `euclidlib`
- [ ] Check that the output of the new reading function(s) follows the agreed interal format of `euclidlib` (TBD)
- [ ] Check that an example of how to use the new function(s) have been added to the documentation (TBD)
